@@ -1,4 +1,4 @@
-# Copyright 2021 Oliver Smith
+# Copyright 2022 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import multiprocessing
 import os
@@ -11,12 +11,13 @@ import sys
 from pmb.config.load import load
 from pmb.config.save import save
 from pmb.config.merge_with_args import merge_with_args
+from pmb.config.sudo import which_sudo
 
 
 #
 # Exported variables (internal configuration)
 #
-version = "1.39.0"
+version = "1.41.0"
 pmb_src = os.path.normpath(os.path.realpath(__file__) + "/../../..")
 apk_keys_path = pmb_src + "/pmb/data/keys"
 arch_native = pmb.parse.arch.alpine_native()
@@ -26,7 +27,8 @@ arch_native = pmb.parse.arch.alpine_native()
 # Update this frequently to prevent a MITM attack with an outdated version
 # (which may contain a vulnerable apk/openssl, and allows an attacker to
 # exploit the system!)
-apk_tools_min_version = {"edge": "2.12.7-r3",
+apk_tools_min_version = {"edge": "2.12.9-r1",
+                         "v3.15": "2.12.7-r3",
                          "v3.14": "2.12.7-r0",
                          "v3.13": "2.12.7-r0",
                          "v3.12": "2.10.8-r0"}
@@ -49,6 +51,7 @@ ondev_min_version = "0.2.0"
 # in sync with README.md, and try to keep the list as small as possible. The
 # idea is to run almost everything in Alpine chroots.
 required_programs = ["git", "openssl", "ps"]
+sudo = which_sudo()
 
 # Keys saved in the config file (mostly what we ask in 'pmbootstrap init')
 config_keys = ["aports",
@@ -288,11 +291,9 @@ necessary_kconfig_options = {
             "EXT4_FS": True,
             "KINETO_GAN": False,
             "PFT": False,
-            "SAMSUNG_TUI": False,
             "SEC_RESTRICT_ROOTING": False,
             "SYSVIPC": True,
             "TMPFS_POSIX_ACL": True,
-            "TZDEV": False,
             "USE_VFB": False,
             "VT": True,
         }
@@ -308,6 +309,12 @@ necessary_kconfig_options = {
             "DEVPTS_MULTIPLE_INSTANCES": True,
         }
     },
+    "<4.14.0": {
+        "all": {
+            "SAMSUNG_TUI": False,
+            "TZDEV": False,
+        }
+    },
     "<5.2.0": {
         "armhf armv7 x86": {
             "LBDAF": True
@@ -339,6 +346,11 @@ necessary_kconfig_options_anbox = {
             "BRIDGE_VLAN_FILTERING": True,
         }
     },
+    ">=3.5": {
+        "all": {
+            "CROSS_MEMORY_ATTACH": True,  # required by Waydroid
+        }
+    },
     ">=4.20.0": {
         "all": {
             "PSI": True,  # required by userspace OOM killer in Waydroid
