@@ -1,4 +1,4 @@
-# Copyright 2021 Oliver Smith
+# Copyright 2022 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import glob
 import json
@@ -396,7 +396,7 @@ def kconfig(args):
                 pkgname = package if package.startswith("linux-") \
                     else "linux-" + package
                 aport = pmb.helpers.pmaports.find(args, pkgname)
-                apkbuild = pmb.parse.apkbuild(args, aport + "/APKBUILD")
+                apkbuild = pmb.parse.apkbuild(f"{aport}/APKBUILD")
                 if "!pmb:kconfigcheck" in apkbuild["options"]:
                     skipped += 1
                     continue
@@ -453,12 +453,12 @@ def apkbuild_parse(args):
         print(package + ":")
         aport = pmb.helpers.pmaports.find(args, package)
         path = aport + "/APKBUILD"
-        print(json.dumps(pmb.parse.apkbuild(args, path), indent=4,
+        print(json.dumps(pmb.parse.apkbuild(path), indent=4,
                          sort_keys=True))
 
 
 def apkindex_parse(args):
-    result = pmb.parse.apkindex.parse(args, args.apkindex_path)
+    result = pmb.parse.apkindex.parse(args.apkindex_path)
     if args.package:
         if args.package not in result:
             raise RuntimeError("Package not found in the APKINDEX: " +
