@@ -1,4 +1,4 @@
-# Copyright 2021 Oliver Smith
+# Copyright 2022 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import fcntl
 import logging
@@ -224,22 +224,25 @@ def sudo_timer_iterate():
     Run sudo -v and schedule a new timer to repeat the same.
     """
 
-    subprocess.Popen(["sudo", "-v"]).wait()
+    if pmb.config.sudo == "sudo":
+        subprocess.Popen(["sudo", "-v"]).wait()
+    else:
+        subprocess.Popen([pmb.config.sudo, "true"]).wait()
 
     timer = threading.Timer(interval=60, function=sudo_timer_iterate)
     timer.daemon = True
     timer.start()
 
 
-def sudo_timer_start(args):
+def sudo_timer_start():
     """
     Start a timer to call sudo -v periodically, so that the password is only
     needed once.
     """
 
-    if "sudo_timer_active" in args.cache:
+    if "sudo_timer_active" in pmb.helpers.other.cache:
         return
-    args.cache["sudo_timer_active"] = True
+    pmb.helpers.other.cache["sudo_timer_active"] = True
 
     sudo_timer_iterate()
 
@@ -305,7 +308,7 @@ def core(args, log_message, cmd, working_dir=None, output="log",
     sanity_checks(output, output_return, check)
 
     if args.sudo_timer and sudo:
-        sudo_timer_start(args)
+        sudo_timer_start()
 
     # Log simplified and full command (pmbootstrap -v)
     logging.debug(log_message)
