@@ -1,4 +1,4 @@
-# Copyright 2021 Oliver Smith
+# Copyright 2022 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import logging
 import os
@@ -64,8 +64,7 @@ def get_nonfree_packages(args, device):
               ["device-nokia-n900-nonfree-firmware"]
     """
     # Read subpackages
-    apkbuild = pmb.parse.apkbuild(args,
-                                  pmb.helpers.devices.find_path(args, device,
+    apkbuild = pmb.parse.apkbuild(pmb.helpers.devices.find_path(args, device,
                                                                 'APKBUILD'))
     subpackages = apkbuild["subpackages"]
 
@@ -190,8 +189,9 @@ def set_user(args):
     """
     Create user with UID 10000 if it doesn't exist.
     Usually the ID for the first user created is 1000, but higher ID is
-    chosen here to avoid conflict with Android UIDs/GIDs.
-
+    chosen here to not cause issues with existing installations. Historically,
+    this was done to avoid conflict with Android UIDs/GIDs, but pmOS has since
+    dropped support for hybris/Halium.
     """
     suffix = "rootfs_" + args.device
     if not pmb.chroot.user_exists(args, args.user, suffix):
@@ -204,6 +204,30 @@ def set_user(args):
         pmb.chroot.root(args, ["addgroup", args.user, group], suffix)
 
 
+def setup_login_chpasswd_user_from_arg(args, suffix):
+    """
+    Set the user's password from what the user passed as --password. Make an
+    effort to not have the password end up in the log file by writing it to
+    a temp file, instead of "echo user:$pass | chpasswd". The user should of
+    course only use this with a test password anyway, but let's be nice and try
+    to have the user protected from accidentally posting their password in
+    any case.
+
+    :param suffix: of the chroot, where passwd will be execute (either the
+                   f"rootfs_{args.device}", or f"installer_{args.device}")
+    """
+    path = "/tmp/pmbootstrap_chpasswd_in"
+    path_outside = f"{args.work}/chroot_{suffix}{path}"
+
+    with open(path_outside, "w", encoding="utf-8") as handle:
+        handle.write(f"{args.user}:{args.password}")
+
+    pmb.chroot.root(args, ["sh", "-c", f"cat {shlex.quote(path)} | chpasswd"],
+                    suffix)
+
+    os.unlink(path_outside)
+
+
 def setup_login(args, suffix):
     """
     Loop until the password for user has been set successfully, and disable
@@ -214,16 +238,19 @@ def setup_login(args, suffix):
     """
     if not args.on_device_installer:
         # User password
-        logging.info(" *** SET LOGIN PASSWORD FOR: '" + args.user + "' ***")
-        while True:
-            try:
-                pmb.chroot.root(args, ["passwd", args.user], suffix,
-                                output="interactive")
-                break
-            except RuntimeError:
-                logging.info("WARNING: Failed to set the password. Try it"
-                             " one more time.")
-                pass
+        logging.info(f" *** SET LOGIN PASSWORD FOR: '{args.user}' ***")
+        if args.password:
+            setup_login_chpasswd_user_from_arg(args, suffix)
+        else:
+            while True:
+                try:
+                    pmb.chroot.root(args, ["passwd", args.user], suffix,
+                                    output="interactive")
+                    break
+                except RuntimeError:
+                    logging.info("WARNING: Failed to set the password. Try it"
+                                 " one more time.")
+                    pass
 
     # Disable root login
     pmb.chroot.root(args, ["passwd", "-l", "root"], suffix)
@@ -862,7 +889,12 @@ def create_device_rootfs(args, step, steps):
         # install it when the ondev installer is running.
         # Always install it when --fde is specified.
         if args.full_disk_encryption or args.on_device_installer:
-            install_packages += ["osk-sdl"]
+            # Pick the most suitable unlocker depending on the packages
+            # selected for installation
+            unlocker = pmb.parse.depends.package_provider(
+                args, "postmarketos-fde-unlocker", install_packages, suffix)
+            if unlocker["pkgname"] not in install_packages:
+                install_packages += [unlocker["pkgname"]]
         else:
             install_packages += ["postmarketos-base-nofde"]
 
