@@ -1,4 +1,4 @@
-# Copyright 2021 Oliver Smith
+# Copyright 2022 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import argparse
 import copy
@@ -55,6 +55,10 @@ def arguments_install(subparser):
                      help="do not enable the SSH daemon by default")
     ret.add_argument("--no-firewall", action="store_true",
                      help="do not enable the firewall by default")
+    ret.add_argument("--password", help="dummy password for automating the"
+                     " installation - will be handled in PLAIN TEXT during"
+                     " install and may be logged to the logfile, do not use an"
+                     " important password!")
 
     # Image type
     group_desc = ret.add_argument_group(
@@ -508,7 +512,7 @@ def package_completer(prefix, action, parser=None, parsed_args=None):
     args = parsed_args
     pmb.config.merge_with_args(args)
     pmb.helpers.args.replace_placeholders(args)
-    pmb.helpers.args.add_cache(args)
+    pmb.helpers.other.init_cache()
     packages = set(
         package for package in pmb.helpers.pmaports.get_list(args)
         if package.startswith(prefix))
