@@ -1,4 +1,4 @@
-# Copyright 2021 Oliver Smith
+# Copyright 2022 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import logging
 import pytest
@@ -82,9 +82,9 @@ def generate(args, monkeypatch, answers):
     remove_contributor_maintainer_lines(args, apkbuild_path_linux)
 
     # Parse the deviceinfo and apkbuilds
-    args.cache["apkbuild"] = {}
-    apkbuild = pmb.parse.apkbuild(args, apkbuild_path)
-    apkbuild_linux = pmb.parse.apkbuild(args, apkbuild_path_linux,
+    pmb.helpers.other.cache["apkbuild"] = {}
+    apkbuild = pmb.parse.apkbuild(apkbuild_path)
+    apkbuild_linux = pmb.parse.apkbuild(apkbuild_path_linux,
                                         check_pkgver=False)
     deviceinfo = pmb.parse.deviceinfo(args, "testsuite-testdevice")
     return (deviceinfo, apkbuild, apkbuild_linux)
