@@ -1,4 +1,4 @@
-# Copyright 2021 Oliver Smith
+# Copyright 2022 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 """ Test pmb.parse.depends """
 import collections
@@ -146,7 +146,8 @@ def test_recurse(args, monkeypatch):
     depends = {
         "test": ["libtest", "so:libtest.so.1"],
         "libtest": ["libtest_depend"],
-        "libtest_depend": [],
+        "libtest_depend": ["!libtest_conflict"],
+        "libtest_conflict": [],
         "so:libtest.so.1": ["libtest_depend"],
     }
 
@@ -158,5 +159,6 @@ def test_recurse(args, monkeypatch):
     # Run
     func = pmb.parse.depends.recurse
     pkgnames = ["test", "so:libtest.so.1"]
-    result = ["test", "so:libtest.so.1", "libtest", "libtest_depend"]
+    result = ["test", "so:libtest.so.1", "libtest", "libtest_depend",
+              "!libtest_conflict"]
     assert func(args, pkgnames) == result
