@@ -1,9 +1,10 @@
-# Copyright 2021 Oliver Smith
+# Copyright 2022 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 """ Test pmb.helpers.run_core """
 import sys
 import subprocess
 import pytest
+import time
 
 import pmb_test  # noqa
 import pmb.helpers.run_core
@@ -81,7 +82,7 @@ def test_foreground_pipe(args):
     assert ret == (-9, "first\n")
 
     # Kill with output timeout as root
-    cmd = ["sudo", "sh", "-c", "printf first; sleep 2; printf second"]
+    cmd = [pmb.config.sudo, "sh", "-c", "printf first; sleep 2; printf second"]
     args.timeout = 0.3
     ret = func(args, cmd, output_return=True, output_timeout=True,
                sudo=True)
@@ -97,7 +98,7 @@ def test_foreground_pipe(args):
     # Check if all child processes are killed after timeout.
     # The first command uses ps to get its process group id (pgid) and echo it
     # to stdout. All of the test commands will be running under that pgid.
-    cmd = ["sudo", "sh", "-c",
+    cmd = [pmb.config.sudo, "sh", "-c",
            "pgid=$(ps -o pgid= | grep ^${1:-$$});echo $pgid | tr -d '\n';" +
            "sleep 10 | sleep 20 | sleep 30"]
     args.timeout = 0.3
@@ -152,3 +153,14 @@ def test_core(args):
     with pytest.raises(RuntimeError) as e:
         func(args, msg, ["sleep", "1"], output="log")
     assert str(e.value).startswith("Command failed:")
+
+
+@pytest.mark.skip_ci
+def test_sudo_timer(args):
+    pmb.helpers.run.root(args, ["whoami"])
+
+    time.sleep(300)
+
+    out = pmb.helpers.run.root(args, ["whoami"])
+
+    assert out == 0
